@@ -1,5 +1,5 @@
 from .base import BaseDeployment
-from .commands import (init, add_deployment, set_deployment, list_commands)
+from .commands import (init, add_deployment, set_deployment)
 
 from .api import virtualenv
 from .decorators import ensure_use_deployment
@@ -15,7 +15,6 @@ __all__ = [
     'init',
     'add_deployment',
     'set_deployment',
-    'list_commands',
 
     'is_easyfab_task',
     'process_directory',
